==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/npc/NPCEntityMonsterImpl.java <==
package cc.thonly.reverie_dreams.entity.npc;

import cc.thonly.reverie_dreams.entity.ai.goal.NPCAttackWithOwnerGoal;
import cc.thonly.reverie_dreams.entity.ai.goal.SleepAtNightGoal;
import cc.thonly.reverie_dreams.entity.ai.goal.WakeUpGoal;
import com.mojang.authlib.properties.Property;
import lombok.Getter;
import lombok.Setter;
import net.minecraft.class_1299;
import net.minecraft.class_1321;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1350;
import net.minecraft.class_1361;
import net.minecraft.class_1376;
import net.minecraft.class_1386;
import net.minecraft.class_1391;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1403;
import net.minecraft.class_1657;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.entity.ai.goal.*;

@Getter
@Setter
public class NPCEntityMonsterImpl extends NPCEntityImpl {


    public NPCEntityMonsterImpl(class_1299<? extends class_1321> entityType, class_1937 world) {
        super(entityType, world);
    }

    public NPCEntityMonsterImpl(class_1299<? extends class_1321> entityType, class_1937 world, Property skin) {
        super(entityType, world, skin);
    }

    @Override
    protected void method_5959() {
        super.method_5959();

        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1386(this));
        this.field_6201.method_6277(2, new WakeUpGoal(this));
        this.field_6201.method_6277(3, new SleepAtNightGoal(this, 1.0));

        this.field_6201.method_6277(4, new class_1391(this, 1.2, stack -> stack.method_31574(class_1802.field_17534), false));
        //        add and remove
        //        this.goalSelector.add(4, this.bowAttackGoal);
        //        this.goalSelector.add(4, this.meleeAttackGoal);
        this.field_6201.method_6277(6, new class_1350(this, 1.0, 2.0f, 10.0f));
        this.field_6201.method_6277(7, new class_1341(this, 1.0));
        this.field_6201.method_6277(8, new class_1394(this, 1.0));

        this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 8.0f));
        this.field_6201.method_6277(10, new class_1361(this, NPCEntityImpl.class, 8.0f));
        this.field_6201.method_6277(10, new class_1376(this));

        this.field_6185.method_6277(1, new class_1403(this));
        this.field_6185.method_6277(2, new NPCAttackWithOwnerGoal(this));
        this.field_6185.method_6277(3, new class_1399(this).method_6318());

    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/npc/NPCEntityMonsterImpl.java <==
package cc.thonly.reverie_dreams.entity.npc;

import cc.thonly.reverie_dreams.entity.ai.goal.NPCAttackWithOwnerGoal;
import cc.thonly.reverie_dreams.entity.ai.goal.SleepAtNightGoal;
import cc.thonly.reverie_dreams.entity.ai.goal.WakeUpGoal;
import cc.thonly.reverie_dreams.data.skin.SkinType;
import lombok.Getter;
import lombok.Setter;
import net.minecraft.class_1299;
import net.minecraft.class_1321;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1350;
import net.minecraft.class_1361;
import net.minecraft.class_1376;
import net.minecraft.class_1386;
import net.minecraft.class_1391;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1403;
import net.minecraft.class_1657;
import net.minecraft.class_1802;
import net.minecraft.class_1937;

@Getter
@Setter
public class NPCEntityMonsterImpl extends BaseNPCLikeEntity {


    public NPCEntityMonsterImpl(class_1299<? extends class_1321> entityType, class_1937 world) {
        super(entityType, world);
    }

    public NPCEntityMonsterImpl(class_1299<? extends class_1321> entityType, class_1937 world, SkinType skinType) {
        super(entityType, world, skinType);
    }

    @Override
    protected void method_5959() {
        super.method_5959();

        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_1386(this));
        this.field_6201.method_6277(2, new WakeUpGoal(this));
        this.field_6201.method_6277(3, new SleepAtNightGoal(this, 1.0));

        this.field_6201.method_6277(4, new class_1391(this, 1.2, stack -> stack.method_31574(class_1802.field_17534), false));
        //        add and remove
        //        this.goalSelector.add(4, this.bowAttackGoal);
        //        this.goalSelector.add(4, this.meleeAttackGoal);
        this.field_6201.method_6277(6, new class_1350(this, 1.0, 2.0f, 10.0f));
        this.field_6201.method_6277(7, new class_1341(this, 1.0));
        this.field_6201.method_6277(8, new class_1394(this, 1.0));

        this.field_6201.method_6277(10, new class_1361(this, class_1657.class, 8.0f));
        this.field_6201.method_6277(10, new class_1361(this, BaseNPCLikeEntity.class, 8.0f));
        this.field_6201.method_6277(10, new class_1376(this));

        this.field_6185.method_6277(1, new class_1403(this));
        this.field_6185.method_6277(2, new NPCAttackWithOwnerGoal(this));
        this.field_6185.method_6277(3, new class_1399(this).method_6318());

    }

}
